fn get_branch(trie: &[u8], i: usize, n: usize, w: usize) -> &[u8] ⓘExpand description
Given a slice starting with an offset table, returns the trie for the given index.
Arguments:
trie= a trie pointing at an offset table (after the branch node and search table)i= the desired index within the offset tablen= the number of items in the offset tablew= the width of the offset table items minus one